@@ -7,9 +7,7 @@ from .integrations_list import integrations_list
 from .slack import slack_commands
 
 
-@click.group(
-    cls=SymGroup, short_help="Perform operations on Sym Integrations", hidden=True
-)
+@click.group(cls=SymGroup, short_help="Perform operations on Sym Integrations")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def integrations(options: GlobalOptions) -> None:
     """Sym Flow CLI commands for operations on Integrations.
