@@ -3,9 +3,8 @@ from typing import Tuple
 import click
 
 from ..version import __version__
-from .symflow import symflow
 
 
-@symflow.command(short_help="print the version")
+@click.command(short_help="Print the version")
 def version() -> None:
     click.echo(__version__)
