@@ -7,8 +7,8 @@ from typing import Tuple
 import click
 import pkce
 import requests
-
 from sym.cli.errors import CliError
+
 from sym.flow.cli.helpers.constants import DEFAULT_SCOPES
 from sym.flow.cli.helpers.login.handler import make_handler
 
@@ -102,15 +102,24 @@ class BrowserRedirectFlow(LoginFlow):
     def redirect_url(self) -> str:
         return f"http://localhost:{self.port}/callback"
 
+    def _new_server(self, options: GlobalOptions, handler):
+        for port in range(self.port, self.port + 10):  # try a few
+            try:
+                return HTTPServer(("localhost", port), handler)
+            except OSError as e:
+                if e.errno not in (48, 98):  # Address already in use
+                    raise
+                options.dprint(f"Port {port} in use, trying to increment...")
+
     def wait_for_code(self, state: str, options: GlobalOptions):
         """
         Starts a server and waits for a request that contains an auth code.
         """
         handler = make_handler(options, state)
-        httpd = HTTPServer(("localhost", self.port), handler)
-        options.dprint(f"Waiting for an auth code at {self.redirect_url}")
-        httpd.handle_request()
-        return getattr(handler, "auth_code", None)
+        with self._new_server(options, handler) as httpd:
+            options.dprint(f"Waiting for an auth code at {self.redirect_url}")
+            httpd.handle_request()
+            return getattr(handler, "auth_code", None)
 
     def gen_state(self) -> str:
         return str(uuid.uuid4())
@@ -136,8 +145,9 @@ class BrowserRedirectFlow(LoginFlow):
                 f"code_challenge={code_challenge}",
                 f"redirect_uri={self.redirect_url}",
                 f"scope={scopes_str}",
-                f"audience={options.api_url}",
+                f"audience=https://api.symops.com",
                 f"state={state}",
+                "prompt=login",
             ]
         )
         url = f"{options.auth_url}/authorize?{query_params}"
