@@ -5,6 +5,7 @@ from uuid import uuid4
 
 import requests
 from dateutil.parser import isoparse
+from requests.exceptions import SSLError
 
 from sym.flow.cli.errors import (
     NotAuthorizedError,
@@ -83,14 +84,19 @@ class SymAPIClient(BaseSymAPIClient):
             params = {}
 
         headers = self.generate_header(auth_required=auth_required)
-        response = requests.get(
-            f"{self.base_url}/{endpoint}", params=params, headers=headers
-        )
+        request_id = headers["X-Sym-Request-ID"]
+
+        try:
+            response = requests.get(
+                f"{self.base_url}/{endpoint}", params=params, headers=headers
+            )
+        except SSLError as e:
+            raise SymAPIUnknownError(response_code=0, request_id=request_id) from e
 
         if validate:
-            self.validate_response(response, headers["X-Sym-Request-ID"])
+            self.validate_response(response, request_id)
 
-        return response, headers["X-Sym-Request-ID"]
+        return response, request_id
 
     def get_organization_from_email(self, email: str) -> Tuple[dict, str]:
         """Exchanges the provided email for the corresponding Organization data."""
