@@ -1,12 +1,9 @@
-from typing import List, Optional, Union, cast
+from typing import List, Union, cast
 from unittest.mock import patch
-from urllib.parse import quote
 
 import pytest
-from click.testing import CliRunner
-
 from sym.cli.errors import CliError
-from sym.cli.helpers.contexts import push_env
+
 from sym.flow.cli.errors import InvalidTokenError, LoginError, SymAPIUnknownError
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.helpers.login.login_flow import LoginFlow
@@ -17,17 +14,6 @@ from sym.flow.cli.tests.conftest import get_mock_response
 TEST_LOGIN_EMAIL = "ci@symops.io"
 
 
-@pytest.fixture
-def auth_token():
-    return AuthToken(
-        access_token="access",
-        refresh_token="refresh",
-        token_type="type",
-        expires_in=86400,
-        scope="scopes",
-    )
-
-
 def mock_login_flow(result: Union[AuthToken, CliError]):
     class MockLoginFlow(LoginFlow):
         def login(self, options: GlobalOptions, org: Organization) -> AuthToken:
@@ -80,19 +66,15 @@ def login_tester(click_setup):
 
 
 @patch(
-    "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get_organization_from_email",
+    "sym.flow.cli.helpers.sym_api_service.SymAPIService.get_organization_from_email",
     return_value=login_test_org,
 )
 @patch(
-    "sym.flow.cli.helpers.sym_api_client.SymAPIClient.verify_login",
+    "sym.flow.cli.helpers.sym_api_service.SymAPIService.verify_login",
     return_value=True,
 )
 def test_login_ok(mock_verify_login, mock_get_org, login_flow, login_tester):
-    expected_output = [
-        "Successfully loaded org: test (12345abc)",
-        "Login succeeded",
-        f"Credentials stored to",
-    ]
+    expected_output = ["Successfully loaded org: test (12345abc)", "Login succeeded"]
     login_tester(
         login_flow=login_flow,
         email=TEST_LOGIN_EMAIL,
@@ -105,13 +87,13 @@ def test_login_ok(mock_verify_login, mock_get_org, login_flow, login_tester):
 
 
 @patch(
-    "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get_organization_from_email",
+    "sym.flow.cli.helpers.sym_api_service.SymAPIService.get_organization_from_email",
     return_value=login_test_org,
 )
 def test_login_login_error(mock_get_org, login_flow_login_error, login_tester):
     expected_output = [
         "Successfully loaded org: test (12345abc)",
-        "Error: Error logging in: test",
+        "Error logging in: test",
     ]
     login_tester(
         login_flow=login_flow_login_error,
@@ -122,7 +104,7 @@ def test_login_login_error(mock_get_org, login_flow_login_error, login_tester):
 
 
 @patch(
-    "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get_organization_from_email",
+    "sym.flow.cli.helpers.sym_api_service.SymAPIService.get_organization_from_email",
     return_value=login_test_org,
 )
 def test_login_invalid_token_error(
@@ -130,7 +112,7 @@ def test_login_invalid_token_error(
 ):
     expected_output = [
         "Successfully loaded org: test (12345abc)",
-        "Error: Unable to parse token: test",
+        "Unable to parse token: test",
     ]
     login_tester(
         login_flow=login_flow_invalid_token_error,
@@ -142,11 +124,11 @@ def test_login_invalid_token_error(
 
 @patch(
     "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get",
-    return_value=get_mock_response(200),
+    return_value=(get_mock_response(200), "test-request-id"),
 )
 def test_login_unknown_org(mock_api_get, login_flow, login_tester):
     expected_output = [
-        f"Error: Unknown organization for email: {TEST_LOGIN_EMAIL}",
+        f"Unknown organization for email: {TEST_LOGIN_EMAIL}",
     ]
     login_tester(
         login_flow=login_flow,
@@ -157,14 +139,14 @@ def test_login_unknown_org(mock_api_get, login_flow, login_tester):
 
 
 @patch(
-    "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get_organization_from_email",
+    "sym.flow.cli.helpers.sym_api_service.SymAPIService.get_organization_from_email",
     return_value=login_test_org,
 )
 def test_login_api_verify_failure(mock_get_org, login_flow, login_tester):
-    expected_output = ["Sym API could not verify this login"]
+    expected_output = ["Sym could not verify this login"]
 
     with patch(
-        "sym.flow.cli.helpers.sym_api_client.SymAPIClient.verify_login",
+        "sym.flow.cli.helpers.sym_api_service.SymAPIService.verify_login",
         side_effect=SymAPIUnknownError(response_code=404, request_id="123"),
     ) as mock_verify_exception:
         login_tester(
@@ -177,7 +159,7 @@ def test_login_api_verify_failure(mock_get_org, login_flow, login_tester):
         mock_verify_exception.assert_called_once_with(TEST_LOGIN_EMAIL)
 
     with patch(
-        "sym.flow.cli.helpers.sym_api_client.SymAPIClient.verify_login",
+        "sym.flow.cli.helpers.sym_api_service.SymAPIService.verify_login",
         return_value=False,
     ) as mock_verify_failed:
         login_tester(
